@@ -13,6 +13,12 @@ from supervised.algorithms.registry import (
     REGRESSION,
 )
 from supervised.preprocessing.preprocessing_utils import PreprocessingUtils
+from supervised.utils.metric import (
+    CatBoostEvalMetricSpearman,
+    CatBoostEvalMetricPearson,
+    CatBoostEvalMetricAveragePrecision,
+)
+
 from supervised.utils.config import LOG_LEVEL
 
 logger = logging.getLogger(__name__)
@@ -22,6 +28,49 @@ from catboost import CatBoostClassifier, CatBoostRegressor, CatBoost, Pool
 import catboost
 
 
+def catboost_eval_metric(ml_task, eval_metric):
+    metric_name_mapping = {
+        BINARY_CLASSIFICATION: {
+            "auc": "AUC",
+            "logloss": "Logloss",
+            "f1": "F1",
+            "average_precision": "average_precision",
+            "accuracy": "Accuracy",
+        },
+        MULTICLASS_CLASSIFICATION: {
+            "logloss": "MultiClass",
+            "f1": "TotalF1:average=Micro",
+            "accuracy": "Accuracy",
+        },
+        REGRESSION: {
+            "rmse": "RMSE",
+            "mae": "MAE",
+            "mape": "MAPE",
+            "r2": "R2",
+            "spearman": "spearman",
+            "pearson": "pearson",
+        },
+    }
+    return metric_name_mapping[ml_task][eval_metric]
+
+
+def catboost_objective(ml_task, eval_metric):
+    objective = "RMSE"
+    if ml_task == BINARY_CLASSIFICATION:
+        objective = "Logloss"
+    elif ml_task == MULTICLASS_CLASSIFICATION:
+        objective = "MultiClass"
+    else:  # ml_task == REGRESSION
+        objective = catboost_eval_metric(REGRESSION, eval_metric)
+        if objective in [
+            "R2",
+            "spearman",
+            "pearson",
+        ]:  # cant optimize them directly
+            objective = "RMSE"
+    return objective
+
+
 class CatBoostAlgorithm(BaseAlgorithm):
 
     algorithm_name = "CatBoost"
@@ -57,7 +106,7 @@ class CatBoostAlgorithm(BaseAlgorithm):
             "random_strength": self.params.get("random_strength", 1.0),
             "loss_function": loss_function,
             "eval_metric": self.params.get("eval_metric", loss_function),
-            "custom_metric": self.params.get("eval_metric", loss_function),
+            # "custom_metric": self.params.get("eval_metric", loss_function),
             "thread_count": self.params.get("n_jobs", -1),
             "verbose": False,
             "allow_writing_files": False,
@@ -74,6 +123,17 @@ class CatBoostAlgorithm(BaseAlgorithm):
             if extra_param in self.params:
                 cat_params[extra_param] = self.params[extra_param]
 
+        self.log_metric_name = cat_params["eval_metric"]
+        if cat_params["eval_metric"] == "spearman":
+            cat_params["eval_metric"] = CatBoostEvalMetricSpearman()
+            self.log_metric_name = "CatBoostEvalMetricSpearman"
+        elif cat_params["eval_metric"] == "pearson":
+            cat_params["eval_metric"] = CatBoostEvalMetricPearson()
+            self.log_metric_name = "CatBoostEvalMetricPearson"
+        elif cat_params["eval_metric"] == "average_precision":
+            cat_params["eval_metric"] = CatBoostEvalMetricAveragePrecision()
+            self.log_metric_name = "CatBoostEvalMetricAveragePrecision"
+
         self.model = Algo(**cat_params)
         self.cat_features = None
         self.best_ntree_limit = 0
@@ -156,7 +216,7 @@ class CatBoostAlgorithm(BaseAlgorithm):
             early_stopping_rounds=self.early_stopping_rounds,
             verbose_eval=False,
         )
-        
+
         if self.model.best_iteration_ is not None:
             if model_init is not None:
                 self.best_ntree_limit = (
@@ -172,21 +232,30 @@ class CatBoostAlgorithm(BaseAlgorithm):
             self.best_ntree_limit = self.model.tree_count_
 
         if log_to_file is not None:
-            metric_name = list(self.model.evals_result_["learn"].keys())[0]
-            train_scores = self.model.evals_result_["learn"][metric_name]
-            validation_scores = self.model.evals_result_["validation"][metric_name]
+            train_scores = self.model.evals_result_["learn"].get(self.log_metric_name)
+            validation_scores = self.model.evals_result_["validation"].get(
+                self.log_metric_name
+            )
             if model_init is not None:
-                train_scores = (
-                    model_init.evals_result_["learn"][metric_name] + train_scores
-                )
-                validation_scores = (
-                    model_init.evals_result_["validation"][metric_name]
-                    + validation_scores
-                )
+                if train_scores is not None:
+                    train_scores = (
+                        model_init.evals_result_["learn"].get(self.log_metric_name)
+                        + train_scores
+                    )
+                if validation_scores is not None:
+                    validation_scores = (
+                        model_init.evals_result_["validation"].get(self.log_metric_name)
+                        + validation_scores
+                    )
+            iteration = None
+            if train_scores is not None:
+                iteration = range(len(validation_scores))
+            elif validation_scores is not None:
+                iteration = range(len(validation_scores))
 
             result = pd.DataFrame(
                 {
-                    "iteration": range(len(train_scores)),
+                    "iteration": iteration,
                     "train": train_scores,
                     "validation": validation_scores,
                 }
@@ -221,6 +290,8 @@ class CatBoostAlgorithm(BaseAlgorithm):
         if self.params["ml_task"] == REGRESSION:
             Algo = CatBoostRegressor
 
+        # loading might throw warnings in the case of custom eval_metric
+        # check https://github.com/catboost/catboost/issues/1169
         self.model = Algo().load_model(model_file_path)
         self.model_file_path = model_file_path
 
@@ -228,11 +299,13 @@ class CatBoostAlgorithm(BaseAlgorithm):
         return "catboost"
 
     def get_metric_name(self):
-        metric = self.params.get("loss_function")
+        metric = self.params.get("eval_metric")
         if metric is None:
             return None
         if metric == "Logloss":
             return "logloss"
+        elif metric == "AUC":
+            return "auc"
         elif metric == "MultiClass":
             return "logloss"
         elif metric == "RMSE":
@@ -241,7 +314,11 @@ class CatBoostAlgorithm(BaseAlgorithm):
             return "mae"
         elif metric == "MAPE":
             return "mape"
-        return None
+        elif metric in ["F1", "TotalF1:average=Micro"]:
+            return "f1"
+        elif metric == "Accuracy":
+            return "accuracy"
+        return metric
 
 
 classification_params = {
