@@ -14,12 +14,71 @@ from supervised.algorithms.registry import (
     MULTICLASS_CLASSIFICATION,
     REGRESSION,
 )
+from supervised.utils.metric import (
+    lightgbm_eval_metric_r2,
+    lightgbm_eval_metric_spearman,
+    lightgbm_eval_metric_pearson,
+    lightgbm_eval_metric_f1,
+    lightgbm_eval_metric_average_precision,
+    lightgbm_eval_metric_accuracy,
+)
 from supervised.utils.config import LOG_LEVEL
 
 logger = logging.getLogger(__name__)
 logger.setLevel(LOG_LEVEL)
 
 
+def lightgbm_objective(ml_task, automl_eval_metric):
+    objective = "regression"
+    if ml_task == BINARY_CLASSIFICATION:
+        objective = "binary"
+    elif ml_task == MULTICLASS_CLASSIFICATION:
+        objective = "multiclass"
+    else:  # ml_task == REGRESSION
+        objective = "regression"
+    return objective
+
+
+def lightgbm_eval_metric(ml_task, automl_eval_metric):
+    metric_name_mapping = {
+        BINARY_CLASSIFICATION: {
+            "auc": "auc",
+            "logloss": "binary_logloss",
+            "f1": "custom",
+            "average_precision": "custom",
+            "accuracy": "custom",
+        },
+        MULTICLASS_CLASSIFICATION: {
+            "logloss": "multi_logloss",
+            "f1": "custom",
+            "accuracy": "custom",
+        },
+        REGRESSION: {
+            "rmse": "rmse",
+            "mae": "mae",
+            "mape": "mape",
+            "r2": "custom",
+            "spearman": "custom",
+            "pearson": "custom",
+        },
+    }
+
+    metric = metric_name_mapping[ml_task][automl_eval_metric]
+    custom_eval_metric = None
+
+    if automl_eval_metric in [
+        "r2",
+        "spearman",
+        "pearson",
+        "f1",
+        "average_precision",
+        "accuracy",
+    ]:
+        custom_eval_metric = automl_eval_metric
+
+    return metric, custom_eval_metric
+
+
 class LightgbmAlgorithm(BaseAlgorithm):
 
     algorithm_name = "LightGBM"
@@ -51,6 +110,7 @@ class LightgbmAlgorithm(BaseAlgorithm):
             "num_threads": n_jobs,
             "verbose": -1,
             "seed": self.params.get("seed", 1),
+            "extra_trees": self.params.get("extra_trees", False),
         }
 
         for extra_param in [
@@ -74,6 +134,21 @@ class LightgbmAlgorithm(BaseAlgorithm):
         if "num_class" in self.params:  # multiclass classification
             self.learner_params["num_class"] = self.params.get("num_class")
 
+        self.custom_eval_metric = None
+        if self.params.get("custom_eval_metric_name") is not None:
+            if self.params["custom_eval_metric_name"] == "r2":
+                self.custom_eval_metric = lightgbm_eval_metric_r2
+            elif self.params["custom_eval_metric_name"] == "spearman":
+                self.custom_eval_metric = lightgbm_eval_metric_spearman
+            elif self.params["custom_eval_metric_name"] == "pearson":
+                self.custom_eval_metric = lightgbm_eval_metric_pearson
+            elif self.params["custom_eval_metric_name"] == "f1":
+                self.custom_eval_metric = lightgbm_eval_metric_f1
+            elif self.params["custom_eval_metric_name"] == "average_precision":
+                self.custom_eval_metric = lightgbm_eval_metric_average_precision
+            elif self.params["custom_eval_metric_name"] == "accuracy":
+                self.custom_eval_metric = lightgbm_eval_metric_accuracy
+
         logger.debug("LightgbmLearner __init__")
 
     def file_extension(self):
@@ -82,6 +157,7 @@ class LightgbmAlgorithm(BaseAlgorithm):
     def update(self, update_params):
         pass
 
+    """
     def get_boosting_rounds(self, lgb_train, valid_sets, esr, max_time):
         if max_time is None:
             max_time = 3600.0
@@ -104,6 +180,7 @@ class LightgbmAlgorithm(BaseAlgorithm):
         iters = max(iters, 100)
         iters = min(iters, 10000)
         return iters
+    """
 
     def fit(
         self,
@@ -120,7 +197,6 @@ class LightgbmAlgorithm(BaseAlgorithm):
             X.to_numpy() if isinstance(X, pd.DataFrame) else X,
             y,
             weight=sample_weight,
-            # params={"max_bin": self.learner_params.get("max_bin", 255)}
         )
         if self.early_stopping_rounds == 0:
             self.model = lgb.train(
@@ -142,7 +218,6 @@ class LightgbmAlgorithm(BaseAlgorithm):
                         else X_validation,
                         y_validation,
                         weight=sample_weight_validation,
-                        # params={"max_bin": self.learner_params.get("max_bin", 255)}
                     ),
                 ]
                 valid_names = ["train", "validation"]
@@ -161,6 +236,7 @@ class LightgbmAlgorithm(BaseAlgorithm):
                 early_stopping_rounds=esr,
                 evals_result=evals_result,
                 verbose_eval=False,
+                feval=self.custom_eval_metric,
             )
 
             if log_to_file is not None:
@@ -197,22 +273,21 @@ class LightgbmAlgorithm(BaseAlgorithm):
 
     def get_metric_name(self):
         metric = self.params.get("metric")
+        custom_metric = self.params.get("custom_eval_metric_name")
+
         if metric is None:
             return None
+        if metric == "custom":
+            return custom_metric
         if metric == "binary_logloss":
             return "logloss"
-        elif metric == "auc":
-            return "auc"
         elif metric == "multi_logloss":
             return "logloss"
-        elif metric == "rmse":
-            return "rmse"
-        return None
+        return metric
 
 
 lgbm_bin_params = {
     "objective": ["binary"],
-    "metric": ["binary_logloss", "auc"],
     "num_leaves": [15, 31, 63, 95, 127],
     "learning_rate": [0.05, 0.1, 0.2],
     "feature_fraction": [0.5, 0.8, 0.9, 1.0],
@@ -222,7 +297,6 @@ lgbm_bin_params = {
 
 classification_bin_default_params = {
     "objective": "binary",
-    "metric": "binary_logloss",
     "num_leaves": 63,
     "learning_rate": 0.05,
     "feature_fraction": 0.9,
@@ -248,11 +322,9 @@ required_preprocessing = [
 
 lgbm_multi_params = copy.deepcopy(lgbm_bin_params)
 lgbm_multi_params["objective"] = ["multiclass"]
-lgbm_multi_params["metric"] = ["multi_logloss"]
 
 classification_multi_default_params = {
     "objective": "multiclass",
-    "metric": "multi_logloss",
     "num_leaves": 63,
     "learning_rate": 0.05,
     "feature_fraction": 0.9,
@@ -262,7 +334,6 @@ classification_multi_default_params = {
 
 lgbr_params = copy.deepcopy(lgbm_bin_params)
 lgbr_params["objective"] = ["regression"]
-lgbr_params["metric"] = ["rmse", "mae", "mape"]
 
 AlgorithmsRegistry.add(
     BINARY_CLASSIFICATION,
@@ -293,7 +364,6 @@ regression_required_preprocessing = [
 
 regression_default_params = {
     "objective": "regression",
-    "metric": "rmse",
     "num_leaves": 63,
     "learning_rate": 0.05,
     "feature_fraction": 0.9,
