@@ -13,6 +13,14 @@ from supervised.algorithms.registry import (
     MULTICLASS_CLASSIFICATION,
     REGRESSION,
 )
+from supervised.utils.metric import (
+    xgboost_eval_metric_r2,
+    xgboost_eval_metric_spearman,
+    xgboost_eval_metric_pearson,
+    xgboost_eval_metric_f1,
+    xgboost_eval_metric_average_precision,
+    xgboost_eval_metric_accuracy,
+)
 from supervised.utils.config import LOG_LEVEL
 
 logger = logging.getLogger(__name__)
@@ -32,6 +40,26 @@ def time_constraint(env):
     pass
 
 
+def xgboost_eval_metric(ml_task, automl_eval_metric):
+    # the mapping is almost the same
+    eval_metric_name = automl_eval_metric
+    if ml_task == MULTICLASS_CLASSIFICATION:
+        if automl_eval_metric == "logloss":
+            eval_metric_name = "mlogloss"
+    return eval_metric_name
+
+
+def xgboost_objective(ml_task, automl_eval_metric):
+    objective = "reg:squarederror"
+    if ml_task == BINARY_CLASSIFICATION:
+        objective = "binary:logistic"
+    elif ml_task == MULTICLASS_CLASSIFICATION:
+        objective = "multi:softprob"
+    else:  # ml_task == REGRESSION
+        objective = "reg:squarederror"
+    return objective
+
+
 class XgbAlgorithm(BaseAlgorithm):
     """
     This is a wrapper over xgboost algorithm.
@@ -61,6 +89,7 @@ class XgbAlgorithm(BaseAlgorithm):
             "n_jobs": self.params.get("n_jobs", -1),
             # "silent": self.params.get("silent", 1),
             "seed": self.params.get("seed", 1),
+            "verbosity": 0,
         }
 
         if "lambda" in self.params:
@@ -77,9 +106,24 @@ class XgbAlgorithm(BaseAlgorithm):
         if "max_rounds" in self.params:
             self.boosting_rounds = self.params["max_rounds"]
 
+        self.custom_eval_metric = None
+        if self.params.get("eval_metric", "") == "r2":
+            self.custom_eval_metric = xgboost_eval_metric_r2
+        elif self.params.get("eval_metric", "") == "spearman":
+            self.custom_eval_metric = xgboost_eval_metric_spearman
+        elif self.params.get("eval_metric", "") == "pearson":
+            self.custom_eval_metric = xgboost_eval_metric_pearson
+        elif self.params.get("eval_metric", "") == "f1":
+            self.custom_eval_metric = xgboost_eval_metric_f1
+        elif self.params.get("eval_metric", "") == "average_precision":
+            self.custom_eval_metric = xgboost_eval_metric_average_precision
+        elif self.params.get("eval_metric", "") == "accuracy":
+            self.custom_eval_metric = xgboost_eval_metric_accuracy
+
         self.best_ntree_limit = 0
         logger.debug("XgbLearner __init__")
-        
+
+    """
     def get_boosting_rounds(self, dtrain, evals, esr, max_time):
         if max_time is None:
             return self.boosting_rounds
@@ -103,6 +147,7 @@ class XgbAlgorithm(BaseAlgorithm):
         iters = max(iters, 100)
         iters = min(iters, 10000)
         return iters
+    """
 
     def fit(
         self,
@@ -142,6 +187,9 @@ class XgbAlgorithm(BaseAlgorithm):
         # just wait till they converge ...
         # boosting_rounds = self.get_boosting_rounds(dtrain, evals, esr, max_time)
 
+        if self.custom_eval_metric is not None:
+            del self.learner_params["eval_metric"]
+
         self.model = xgb.train(
             self.learner_params,
             dtrain,
@@ -149,7 +197,8 @@ class XgbAlgorithm(BaseAlgorithm):
             evals=evals,
             early_stopping_rounds=esr,
             evals_result=evals_result,
-            verbose_eval=False
+            verbose_eval=False,
+            feval=self.custom_eval_metric
             # callbacks=[time_constraint] # callback slows down by factor ~8
         )
 
@@ -158,7 +207,9 @@ class XgbAlgorithm(BaseAlgorithm):
         # print(self.model.best_ntree_limit, num_trees)
 
         if log_to_file is not None:
-            metric_name = list(evals_result["train"].keys())[0]
+
+            metric_name = list(evals_result["train"].keys())[-1]
+
             result = pd.DataFrame(
                 {
                     "iteration": range(len(evals_result["train"][metric_name])),
@@ -166,6 +217,20 @@ class XgbAlgorithm(BaseAlgorithm):
                     "validation": evals_result["validation"][metric_name],
                 }
             )
+            # it a is custom metric
+            # that is always minimized
+            # we need to revert it
+            if metric_name in [
+                "r2",
+                "spearman",
+                "pearson",
+                "f1",
+                "average_precision",
+                "accuracy",
+            ]:
+                result["train"] *= -1.0
+                result["validation"] *= -1.0
+
             result.to_csv(log_to_file, index=False, header=False)
 
         # save best_ntree_limit because of:
@@ -219,26 +284,14 @@ class XgbAlgorithm(BaseAlgorithm):
         metric = self.params.get("eval_metric")
         if metric is None:
             return None
-        if metric == "logloss":
+        if metric == "mlogloss":
             return "logloss"
-        elif metric == "auc":
-            return "auc"
-        elif metric == "mlogloss":
-            return "logloss"
-        elif metric == "rmse":
-            return "rmse"
-        elif metric == "mae":
-            return "mae"
-        elif metric == "mape":
-            return "mape"
-
-        return None
+        return metric
 
 
 # For binary classification target should be 0, 1. There should be no NaNs in target.
 xgb_bin_class_params = {
     "objective": ["binary:logistic"],
-    "eval_metric": ["logloss", "auc"],
     "eta": [0.05, 0.075, 0.1, 0.15],
     "max_depth": [4, 5, 6, 7, 8, 9],
     "min_child_weight": [1, 5, 10, 25, 50],
@@ -248,7 +301,6 @@ xgb_bin_class_params = {
 
 classification_bin_default_params = {
     "objective": "binary:logistic",
-    "eval_metric": "logloss",
     "eta": 0.075,
     "max_depth": 6,
     "min_child_weight": 1,
@@ -258,17 +310,16 @@ classification_bin_default_params = {
 
 xgb_regression_params = dict(xgb_bin_class_params)
 xgb_regression_params["objective"] = ["reg:squarederror"]
-xgb_regression_params["eval_metric"] = ["rmse", "mae", "mape"]
+# xgb_regression_params["eval_metric"] = ["rmse", "mae", "mape"]
 xgb_regression_params["max_depth"] = [4, 5, 6, 7, 8, 9]
 
 
 xgb_multi_class_params = dict(xgb_bin_class_params)
 xgb_multi_class_params["objective"] = ["multi:softprob"]
-xgb_multi_class_params["eval_metric"] = ["mlogloss"]
+# xgb_multi_class_params["eval_metric"] = ["mlogloss"]
 
 classification_multi_default_params = {
     "objective": "multi:softprob",
-    "eval_metric": "mlogloss",
     "eta": 0.075,
     "max_depth": 6,
     "min_child_weight": 1,
@@ -279,7 +330,6 @@ classification_multi_default_params = {
 
 regression_default_params = {
     "objective": "reg:squarederror",
-    "eval_metric": "rmse",
     "eta": 0.075,
     "max_depth": 6,
     "min_child_weight": 1,
