@@ -100,6 +100,7 @@ class BaseAutoML(BaseEstimator, ABC):
         self._max_single_prediction_time = None
         self._optuna_time_budget = None
         self._optuna_init_params = {}
+        self._optuna_verbose = True
         self._n_jobs = -1
 
     def _get_tuner_params(
@@ -908,6 +909,7 @@ class BaseAutoML(BaseEstimator, ABC):
         self._max_single_prediction_time = self._get_max_single_prediction_time()
         self._optuna_time_budget = self._get_optuna_time_budget()
         self._optuna_init_params = self._get_optuna_init_params()
+        self._optuna_verbose = self._get_optuna_verbose()
         self._n_jobs = self._get_n_jobs()
         self._random_state = self._get_random_state()
 
@@ -931,6 +933,22 @@ class BaseAutoML(BaseEstimator, ABC):
             self._check_can_load()
 
             self.verbose_print(f"AutoML directory: {self._results_path}")
+            if self._mode == "Optuna" and self._total_time_limit is not None:
+                ttl = int(
+                    self._total_time_limit
+                    + len(self._algorithms) * self._optuna_time_budget
+                )
+                self.verbose_print("Expected computing time:")
+                self.verbose_print(
+                    f"Total training time: Optuna + ML training = {ttl} seconds"
+                )
+                self.verbose_print(
+                    f"Total Optuna time: len(algorithms) * optuna_time_budget = {int(len(self._algorithms) * self._optuna_time_budget)} seconds"
+                )
+                self.verbose_print(
+                    f"Total ML model training time: {int(self._total_time_limit)} seconds"
+                )
+
             self.verbose_print(
                 f"The task is {self._ml_task} with evaluation metric {self._eval_metric}"
             )
@@ -959,6 +977,7 @@ class BaseAutoML(BaseEstimator, ABC):
                 ),
                 self._algorithms,
                 self._ml_task,
+                self._eval_metric,
                 self._validation_strategy,
                 self._explain_level,
                 self._data_info,
@@ -972,6 +991,7 @@ class BaseAutoML(BaseEstimator, ABC):
                 self._mix_encoding,
                 self._optuna_time_budget,
                 self._optuna_init_params,
+                self._optuna_verbose,
                 self._n_jobs,
                 self._random_state,
             )
@@ -1430,6 +1450,7 @@ class BaseAutoML(BaseEstimator, ABC):
                     "LightGBM",
                     "Xgboost",
                     "CatBoost",
+                    "Neural Network",
                 ]
         else:
             return deepcopy(self.algorithms)
@@ -1529,7 +1550,7 @@ class BaseAutoML(BaseEstimator, ABC):
             if self._get_mode() == "Compete":
                 return True
             if self._get_mode() == "Optuna":
-                return True
+                return False
         else:
             return deepcopy(self.golden_features)
 
@@ -1544,7 +1565,7 @@ class BaseAutoML(BaseEstimator, ABC):
             if self._get_mode() == "Compete":
                 return True
             if self._get_mode() == "Optuna":
-                return True
+                return False
         else:
             return deepcopy(self.features_selection)
 
@@ -1619,7 +1640,7 @@ class BaseAutoML(BaseEstimator, ABC):
             if self._get_mode() == "Compete":
                 return True
             if self._get_mode() == "Optuna":
-                return True
+                return False
         else:
             return deepcopy(self.kmeans_features)
 
@@ -1634,7 +1655,7 @@ class BaseAutoML(BaseEstimator, ABC):
             if self._get_mode() == "Compete":
                 return True
             if self._get_mode() == "Optuna":
-                return True
+                return False
         else:
             return deepcopy(self.mix_encoding)
 
@@ -1670,6 +1691,14 @@ class BaseAutoML(BaseEstimator, ABC):
             return {}
         return deepcopy(self.optuna_init_params)
 
+    def _get_optuna_verbose(self):
+        """ Gets the current optuna_verbose"""
+        self._validate_optuna_verbose()
+        # use only for mode Optuna
+        if self._get_mode() != "Optuna":
+            return True
+        return deepcopy(self.optuna_verbose)
+
     def _get_n_jobs(self):
         """ Gets the current n_jobs"""
         self._validate_n_jobs()
@@ -1749,18 +1778,21 @@ class BaseAutoML(BaseEstimator, ABC):
         if (self._get_ml_task() == BINARY_CLASSIFICATION) and self.eval_metric not in [
             "logloss",
             "auc",
+            "f1",
+            "average_precision",
+            "accuracy"
         ]:
             raise ValueError(
                 f"Metric {self.eval_metric} is not allowed in ML task: {self._get_ml_task()}. \
-                    Use 'logloss'"
+                    Use 'logloss', 'auc', 'f1', 'average_precision', or 'accuracy'"
             )
 
         elif (
             self._get_ml_task() == MULTICLASS_CLASSIFICATION
-        ) and self.eval_metric != "logloss":
+        ) and self.eval_metric not in ["logloss", "f1", "accuracy"]:
             raise ValueError(
                 f"Metric {self.eval_metric} is not allowed in ML task: {self._get_ml_task()}. \
-                    Use 'logloss'"
+                    Use 'logloss', 'f1', or 'accuracy'"
             )
 
         elif self._get_ml_task() == REGRESSION and self.eval_metric not in [
@@ -1769,10 +1801,12 @@ class BaseAutoML(BaseEstimator, ABC):
             "mae",
             "r2",
             "mape",
+            "spearman",
+            "pearson",
         ]:
             raise ValueError(
                 f"Metric {self.eval_metric} is not allowed in ML task: {self._get_ml_task()}. \
-                Use 'rmse'"
+                Use 'rmse', 'mse', 'mae', 'r2', 'mape', 'spearman', or 'pearson'"
             )
 
     def _validate_validation_strategy(self):
@@ -1895,6 +1929,12 @@ class BaseAutoML(BaseEstimator, ABC):
                 f"Expected 'optuna_init_params' to be a dict, got '{type(self.optuna_init_params)}'"
             )
 
+    def _validate_optuna_verbose(self):
+        """ Validates optuna_verbose parameter"""
+        if self.optuna_verbose is None:
+            return
+        check_bool(self.optuna_verbose, "optuna_verbose")
+
     def _validate_n_jobs(self):
         """ Validates mix_encoding parameter"""
         check_integer(self.n_jobs, "n_jobs")
