@@ -12,3 +12,9 @@ class AutoMLException(Exception):
     def __init__(self, message):
         super(AutoMLException, self).__init__(message)
         logger.error(message)
+
+
+class NotTrainedException(Exception):
+    def __init__(self, message):
+        super(NotTrainedException, self).__init__(message)
+        logger.debug(message)
