@@ -76,6 +76,10 @@ class ModelFramework:
         self._single_prediction_time = None  # prediction time on single sample
         self._optuna_time_budget = params.get("optuna_time_budget")
         self._optuna_init_params = params.get("optuna_init_params", {})
+        self._optuna_verbose = params.get("optuna_verbose", True)
+
+        # the automl random state from AutoML constructor, used in Optuna optimizer
+        self._automl_random_state = params.get("automl_random_state", 42)
 
     def get_train_time(self):
         return self.train_time
@@ -137,9 +141,9 @@ class ModelFramework:
                 eval_metric=self.get_metric(),
                 time_budget=self._optuna_time_budget,
                 init_params=self._optuna_init_params,
-                verbose=True,#False,
+                verbose=self._optuna_verbose,
                 n_jobs=self.learner_params.get("n_jobs", -1),
-                random_state=self.learner_params.get("seed", 42),
+                random_state=self._automl_random_state,
             )
 
         self.validation = ValidationStep(self.validation_params)
@@ -182,6 +186,7 @@ class ModelFramework:
                 )
 
                 if optuna_tuner is not None:
+                    optuna_start_time = time.time()
                     self.learner_params = optuna_tuner.optimize(
                         self.learner_params.get("model_type", ""),
                         self.params.get("data_type", ""),
@@ -193,6 +198,8 @@ class ModelFramework:
                         sample_weight_validation,
                         self.learner_params,
                     )
+                    # exclude optuna optimize time from model training
+                    start_time += time.time() - optuna_start_time
 
                 self.learner_params["explain_level"] = self._explain_level
                 self.learners += [
