@@ -17,6 +17,10 @@ from supervised.algorithms.registry import (
     REGRESSION,
 )
 
+from supervised.algorithms.xgboost import xgboost_eval_metric
+from supervised.algorithms.lightgbm import lightgbm_eval_metric
+from supervised.algorithms.catboost import catboost_eval_metric
+
 import logging
 from supervised.utils.config import LOG_LEVEL
 
@@ -30,6 +34,7 @@ class MljarTuner:
         tuner_params,
         algorithms,
         ml_task,
+        eval_metric,
         validation_strategy,
         explain_level,
         data_info,
@@ -43,6 +48,7 @@ class MljarTuner:
         mix_encoding,
         optuna_time_budget,
         optuna_init_params,
+        optuna_verbose,
         n_jobs,
         seed,
     ):
@@ -65,6 +71,8 @@ class MljarTuner:
         self._mix_encoding = mix_encoding
         self._optuna_time_budget = optuna_time_budget
         self._optuna_init_params = optuna_init_params
+        self._optuna_verbose = optuna_verbose
+        self._eval_metric = eval_metric
         self._n_jobs = n_jobs
         self._seed = seed
         self._unique_params_keys = []
@@ -254,6 +262,8 @@ class MljarTuner:
             # didnt find anything matching the step, return empty array
             return []
         except Exception as e:
+            # import traceback
+            # print(traceback.format_exc())
             return []
 
     def get_params_stack_models(self, stacked_models):
@@ -263,7 +273,15 @@ class MljarTuner:
         X_train_stacked_path = ""
         added_columns = []
 
-        model_types = ["Xgboost", "LightGBM", "CatBoost"]
+        # model_types = ["Xgboost", "LightGBM", "CatBoost"]
+        model_types = [
+            "Xgboost",
+            "LightGBM",
+            "CatBoost",
+            "Random Forest",
+            "Extra Trees",
+            "Neural Network",
+        ]
         generated_params = {m: [] for m in model_types}
         types_score_order = []
         # resue old params
@@ -295,6 +313,7 @@ class MljarTuner:
             if self._optuna_time_budget is not None:
                 params["optuna_time_budget"] = self._optuna_time_budget
                 params["optuna_init_params"] = self._optuna_init_params
+                params["optuna_verbose"] = self._optuna_verbose
 
             if "model_architecture_json" in params["learner"]:
                 # the new model will be created with wider input size
@@ -428,11 +447,13 @@ class MljarTuner:
             if self._optuna_time_budget is not None:
                 params["optuna_time_budget"] = self._optuna_time_budget
                 params["optuna_init_params"] = self._optuna_init_params
+                params["optuna_verbose"] = self._optuna_verbose
 
             unique_params_key = MljarTuner.get_params_key(params)
             if unique_params_key not in self._unique_params_keys:
                 generated_params += [params]
                 models_cnt += 1
+
         return generated_params
 
     def get_not_so_random_params(self, models_cnt):
@@ -473,6 +494,7 @@ class MljarTuner:
                 if self._optuna_time_budget is not None:
                     params["optuna_time_budget"] = self._optuna_time_budget
                     params["optuna_init_params"] = self._optuna_init_params
+                    params["optuna_verbose"] = self._optuna_verbose
 
                 unique_params_key = MljarTuner.get_params_key(params)
                 if unique_params_key not in self._unique_params_keys:
@@ -663,6 +685,7 @@ class MljarTuner:
                 if self._optuna_time_budget is not None:
                     params["optuna_time_budget"] = self._optuna_time_budget
                     params["optuna_init_params"] = self._optuna_init_params
+                    params["optuna_verbose"] = self._optuna_verbose
 
                 if "model_architecture_json" in params["learner"]:
                     del params["learner"]["model_architecture_json"]
@@ -729,6 +752,7 @@ class MljarTuner:
             if self._optuna_time_budget is not None:
                 params["optuna_time_budget"] = self._optuna_time_budget
                 params["optuna_init_params"] = self._optuna_init_params
+                params["optuna_verbose"] = self._optuna_verbose
 
             if "model_architecture_json" in params["learner"]:
                 del params["learner"]["model_architecture_json"]
@@ -759,6 +783,7 @@ class MljarTuner:
             if self._optuna_time_budget is not None:
                 params["optuna_time_budget"] = self._optuna_time_budget
                 params["optuna_init_params"] = self._optuna_init_params
+                params["optuna_verbose"] = self._optuna_verbose
 
             if "model_architecture_json" in params["learner"]:
                 del params["learner"]["model_architecture_json"]
@@ -890,6 +915,7 @@ class MljarTuner:
                 if self._optuna_time_budget is not None:
                     params["optuna_time_budget"] = self._optuna_time_budget
                     params["optuna_init_params"] = self._optuna_init_params
+                    params["optuna_verbose"] = self._optuna_verbose
 
                 if "model_architecture_json" in params["learner"]:
                     del params["learner"]["model_architecture_json"]
@@ -912,6 +938,28 @@ class MljarTuner:
         if model_params is None:
             return None
 
+        # set eval metric
+        if model_info["class"].algorithm_short_name == "Xgboost":
+            model_params["eval_metric"] = xgboost_eval_metric(
+                self._ml_task, self._eval_metric
+            )
+        if model_info["class"].algorithm_short_name == "LightGBM":
+            metric, custom_metric = lightgbm_eval_metric(
+                self._ml_task, self._eval_metric
+            )
+            model_params["metric"] = metric
+            model_params["custom_eval_metric_name"] = custom_metric
+        if model_info["class"].algorithm_short_name == "CatBoost":
+            model_params["eval_metric"] = catboost_eval_metric(
+                self._ml_task, self._eval_metric
+            )
+        elif model_info["class"].algorithm_short_name in [
+            "Random Forest",
+            "Extra Trees",
+        ]:
+            model_params["eval_metric_name"] = self._eval_metric
+            model_params["ml_task"] = self._ml_task
+
         required_preprocessing = model_info["required_preprocessing"]
         model_additional = model_info["additional"]
         preprocessing_params = PreprocessingTuner.get(
@@ -928,6 +976,7 @@ class MljarTuner:
                 "n_jobs": self._n_jobs,
                 **model_params,
             },
+            "automl_random_state": self._seed,
         }
 
         if self._data_info.get("num_class") is not None:
@@ -1021,6 +1070,8 @@ class MljarTuner:
         if self._optuna_time_budget is not None:
             params["optuna_time_budget"] = self._optuna_time_budget
             params["optuna_init_params"] = self._optuna_init_params
+            params["optuna_verbose"] = self._optuna_verbose
+
         unique_params_key = MljarTuner.get_params_key(params)
 
         if unique_params_key not in self._unique_params_keys:
