@@ -44,8 +44,10 @@ class PermutationImportance:
         # for scoring check https://scikit-learn.org/stable/modules/model_evaluation.html#scoring-parameter
         if ml_task == BINARY_CLASSIFICATION:
             scoring = log_loss_scorer
+            model.classes_ = np.unique(y_validation)
         elif ml_task == MULTICLASS_CLASSIFICATION:
             scoring = log_loss_scorer
+            model.classes_ = np.unique(y_validation)
         else:
             scoring = "neg_mean_squared_error"
 
@@ -55,11 +57,11 @@ class PermutationImportance:
                 # subsample validation data to speed-up importance computation
                 # in the case of large number of columns, it can take a lot of time
                 rows, cols = X_validation.shape
-                if cols > 5000:
+                if cols > 5000 and rows > 100:
                     X_vald, _, y_vald, _ = subsample(
                         X_validation, y_validation, train_size=100, ml_task=ml_task
                     )
-                elif cols > 50 and rows * cols > 200000:
+                elif cols > 50 and rows * cols > 200000 and rows > 1000:
                     X_vald, _, y_vald, _ = subsample(
                         X_validation, y_validation, train_size=1000, ml_task=ml_task
                     )
@@ -91,4 +93,5 @@ class PermutationImportance:
                 index=False,
             )
         except Exception as e:
+            print(str(e))
             print("Problem during computing permutation importance. Skipping ...")
